# Light Pandas

## Brief

**Pandas** is a great tools for data analysis.<br>
But the execution speed is very slow. So I try to provide a light library.
The properties as below:

- **Light Pandas** only provide part of functions which provided by pandas.
- The code can compactible pandas. That's mean the code should execute OK if replaced light pandas by pandas.
- **Light Pandas** execution speed is faster than pandas.
- The cell type only provide str.
- TBD

## Example
